@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020 Tianjin KYLIN Information Technology Co., Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,18 @@
 #include "oneconnform.h"
 #include "ui_oneconnform.h"
 #include "mainwindow.h"
+#include "kylin-dbus-interface.h"
 #include "kylin-network-interface.h"
 #include "wireless-security/dlgconnhidwifi.h"
 #include "utils.h"
 
+#include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusMessage>
+#include <QtDBus/QDBusInterface>
+#include <QtDBus/QDBusObjectPath>
+#include <QDBusReply>
+#include <QDBusObjectPath>
+
 extern int currentActWifiSignalLv;
 
 OneConnForm::OneConnForm(QWidget *parent, MainWindow *mainWindow, ConfForm *confForm, KSimpleNM *ksnm) :
@@ -42,7 +50,15 @@ OneConnForm::OneConnForm(QWidget *parent, MainWindow *mainWindow, ConfForm *conf
     ui->lePassword->setEchoMode(QLineEdit::Normal);
     ui->btnConnPWD->setEnabled(false);
 
-    ui->lbInfo->setStyleSheet("QLabel{font-size:14px;color:rgba(255,255,255,0.57);line-height:24px;}");
+    leQssLow = "QLineEdit{border:none;background:transparent;font-size:14px;color:rgba(255,255,255,0.57);font-family:Noto Sans CJK SC;}";
+    leQssHigh = "QLineEdit{border:none;background:transparent;font-size:14px;color:rgba(255,255,255,0.91);font-family:Noto Sans CJK SC;}";
+
+    ui->leInfo_1->setStyleSheet(leQssLow);
+    ui->leInfo_2->setStyleSheet(leQssLow);
+    ui->leInfo_3->setStyleSheet(leQssLow);
+    ui->leInfo_1->setEnabled(false);
+    ui->leInfo_2->setEnabled(false);
+    ui->leInfo_3->setEnabled(false);
     ui->btnInfo->setStyleSheet("QPushButton{border:none;background:transparent;}");
     ui->wbg->setStyleSheet("#wbg{border-radius:4px;background-color:rgba(255,255,255,0);}");
     ui->wbg_2->setStyleSheet("#wbg_2{border-radius:4px;background-color:rgba(255,255,255,0.1);}");
@@ -85,7 +101,9 @@ OneConnForm::OneConnForm(QWidget *parent, MainWindow *mainWindow, ConfForm *conf
     ui->wbg_2->hide();
     ui->wbg_3->hide();
     ui->lbName->show();
-    ui->lbInfo->hide();
+    ui->leInfo_1->hide();
+    ui->leInfo_2->hide();
+    ui->leInfo_3->hide();
     ui->lePassword->hide();
     ui->checkBoxPwd->hide();
     ui->checkBoxPwd->setChecked(true);
@@ -126,36 +144,40 @@ OneConnForm::OneConnForm(QWidget *parent, MainWindow *mainWindow, ConfForm *conf
 
 OneConnForm::~OneConnForm()
 {
-    m_notify->deleteLater();
     delete ui;
 }
 
-void OneConnForm::mousePressEvent(QMouseEvent *){
+void OneConnForm::mousePressEvent(QMouseEvent *)
+{
     emit selectedOneWifiForm(wifiName, H_WIFI_ITEM_BIG_EXTEND);
 }
 
 //事件过滤器
 bool OneConnForm::eventFilter(QObject *obj, QEvent *event)
 {
-    if (obj == ui->btnInfo){
-        if(event->type() == QEvent::HoverEnter) {
-            ui->lbInfo->setStyleSheet("QLabel{font-size:14px;color:rgba(255,255,255,0.91);line-height:24px;}");
+    if (obj == ui->btnInfo) {
+        if (event->type() == QEvent::HoverEnter) {
+            ui->leInfo_1->setStyleSheet(leQssHigh);
+            ui->leInfo_2->setStyleSheet(leQssHigh);
+            ui->leInfo_3->setStyleSheet(leQssHigh);
             return true;
-        } else if(event->type() == QEvent::HoverLeave){
-            ui->lbInfo->setStyleSheet("QLabel{font-size:14px;color:rgba(255,255,255,0.57);line-height:24px;}");
+        } else if(event->type() == QEvent::HoverLeave) {
+            ui->leInfo_1->setStyleSheet(leQssLow);
+            ui->leInfo_2->setStyleSheet(leQssLow);
+            ui->leInfo_3->setStyleSheet(leQssLow);
             return true;
         }
-    }else if (obj == this){
+    } else if (obj == this) {
         if(event->type() == QEvent::HoverEnter) {
-            if (!this->isTopItem){
-                if (!this->isSelected){
+            if (!this->isTopItem) {
+                if (!this->isSelected) {
                     ui->btnConn->show();
                     ui->wbg->setStyleSheet("#wbg{border-radius:4px;background-color:rgba(255,255,255,0.1);}");
                     ui->wbg->show();
                 }
             }
             return true;
-        } else if(event->type() == QEvent::HoverLeave){
+        } else if (event->type() == QEvent::HoverLeave) {
             ui->btnConn->hide();
             ui->wbg->setStyleSheet("#wbg{border-radius:4px;background-color:rgba(255,255,255,0);}");
             ui->wbg->hide();
@@ -163,10 +185,10 @@ bool OneConnForm::eventFilter(QObject *obj, QEvent *event)
         }
     }
 
-    if(obj == ui->lePassword){
-        if(event->type() == QEvent::MouseButtonPress){
+    if (obj == ui->lePassword) {
+        if (event->type() == QEvent::MouseButtonPress) {
             this->setLePassword();
-        }else{
+        } else {
             return false;
         }
     }
@@ -175,11 +197,12 @@ bool OneConnForm::eventFilter(QObject *obj, QEvent *event)
 }
 
 // 是否当前连接的网络，字体设置不同
-void OneConnForm::setAct(bool isAct){
-    if(isAct){
+void OneConnForm::setAct(bool isAct)
+{
+    if (isAct) {
         ui->lbName->setStyleSheet("QLabel{font-size:14px;color:#ffffff;}");
         ui->lbConned->show();
-    }else{
+    } else {
         ui->lbName->setStyleSheet("QLabel{font-size:14px;color:#ffffff;}");
         ui->lbConned->hide();
     }
@@ -188,7 +211,7 @@ void OneConnForm::setAct(bool isAct){
 
 void OneConnForm::setLePassword()
 {
-    if(ui->lePassword->text() == "Input Password..."  || ui->lePassword->text() == "输入密码..."){
+    if (ui->lePassword->text() == "Input Password..."  || ui->lePassword->text() == "输入密码...") {
         ui->lePassword->setText(tr(""));
         ui->lePassword->setEchoMode(QLineEdit::Password);
         ui->checkBoxPwd->setChecked(false);
@@ -196,18 +219,24 @@ void OneConnForm::setLePassword()
 }
 
 //点击窗口最上面的item时
-void OneConnForm::setTopItem(bool isSelected){
-    if(isSelected){
+void OneConnForm::setTopItem(bool isSelected)
+{
+    if (isSelected) {
         resize(W_ITEM, H_ITEM_BIG);
         ui->wbg_3->show();
-        ui->lbInfo->show();
+        ui->leInfo_1->show();
+        ui->leInfo_2->show();
+        ui->leInfo_3->show();
 
         this->isSelected = true;
-    }else{
+    } else {
         resize(W_ITEM, H_ITEM);
         ui->lePassword->setText("");
         ui->wbg_3->hide();
-        ui->lbInfo->hide();
+        ui->leInfo_1->hide();
+        ui->leInfo_2->hide();
+        ui->leInfo_3->hide();
+
 
         this->isSelected = false;
     }
@@ -223,32 +252,35 @@ void OneConnForm::setTopItem(bool isSelected){
     ui->btnHideConn->hide();
     ui->btnInfo->show();
 
-    if (isConnected){
-        if (this->isWaiting){
+    if (isConnected) {
+        if (this->isWaiting) {
             ui->btnDisConn->hide();
-        }else{
+        } else {
             ui->btnDisConn->show();
         }
-    }else{
+    } else {
         ui->btnDisConn->hide();
     }
 
     this->isTopItem = true;
 }
 // 点击窗口下面的item时
-void OneConnForm::setSelected(bool isSelected, bool isCurrName){
-    if(isSelected){
+void OneConnForm::setSelected(bool isSelected, bool isCurrName)
+{
+    if (isSelected) {
         resize(W_ITEM, H_ITEM_BIG);
         ui->line->move(X_LINE_BIG_EXTEND, Y_LINE_BIG_EXTEND);
         ui->wbg->hide();
         ui->wbg_2->hide();
         ui->wbg_3->show();
-        ui->lbInfo->show();
+        ui->leInfo_1->show();
+        ui->leInfo_2->show();
+        ui->leInfo_3->show();
         ui->btnConn->hide();
         ui->btnConnSub->show();
 
         this->isSelected = true;
-    }else{
+    } else {
         resize(W_ITEM, H_ITEM);
         ui->lePassword->setText(tr("Input Password..."));//"输入密码..."
         ui->lePassword->setStyleSheet("QLineEdit{border:1px solid rgba(61,107,229,1);border-radius:4px;"
@@ -260,10 +292,13 @@ void OneConnForm::setSelected(bool isSelected, bool isCurrName){
         ui->wbg->show();
         ui->wbg_2->hide();
         ui->wbg_3->hide();
-        ui->lbInfo->hide();
-        if (isCurrName){
+        ui->leInfo_1->hide();
+        ui->leInfo_2->hide();
+        ui->leInfo_3->hide();
+
+        if (isCurrName) {
             ui->btnConn->show();
-        }else{
+        } else {
             ui->btnConn->hide();
         }
         ui->btnConnSub->hide();
@@ -282,8 +317,9 @@ void OneConnForm::setSelected(bool isSelected, bool isCurrName){
     this->isTopItem = false;
 }
 // 点击连接隐藏wifi的item时
-void OneConnForm::setHideItem(bool isHideItem, bool isShowHideBtn){
-    if (isHideItem){
+void OneConnForm::setHideItem(bool isHideItem, bool isShowHideBtn)
+{
+    if (isHideItem) {
         ui->lbName->move(14, 20);
         ui->wbg->hide();
         ui->btnConn->hide();
@@ -293,24 +329,26 @@ void OneConnForm::setHideItem(bool isHideItem, bool isShowHideBtn){
         ui->btnConn->show();
     }
 
-    if (isShowHideBtn){
+    if (isShowHideBtn) {
         ui->btnHideConn->show();
     } else{
         ui->btnHideConn->hide();
     }
 }
 
-void OneConnForm::setConnedString(bool showLable, QString str, QString str1){
-    if (!showLable){
+void OneConnForm::setConnedString(bool showLable, QString str, QString str1)
+{
+    if (!showLable) {
         ui->lbConned->setText(str1);
         ui->lbConned->hide();
         ui->lbName->move(63, 18);
-    }else{
+    } else {
         ui->lbConned->setText(str);
     }
 }
 
-void OneConnForm::setName(QString name){
+void OneConnForm::setName(QString name)
+{
     ui->lbName->setText(name);
     wifiName = name;
 }
@@ -325,65 +363,67 @@ QString OneConnForm::getName()
     return ui->lbName->text();
 }
 
-void OneConnForm::setRate(QString rate){
-//    QString txt(tr("Rate"));//"速率"
-//    this->setToolTip("<span style=\"font-size:14px;border:none;background-color:#3593b5;color:white;\">&nbsp; " + txt + ": " + rate + " &nbsp;</span>");
-//    this->setToolTip(txt + ":" + rate);
+void OneConnForm::setRate(QString rate)
+{
+    QString txt(tr("Rate"));//"速率"
+    this->setToolTip("<span style=\"font-size:14px;border:none;background-color:#3593b5;color:white;\">&nbsp; " + txt + ": " + rate + " &nbsp;</span>");
+    this->setToolTip(txt + ":" + rate);
 }
 
 void OneConnForm::setLine(bool isShow)
 {
-    if(isShow){
+    if (isShow) {
         ui->line->show();
-    }else{
+    } else {
         ui->line->hide();
     }
 }
 
-void OneConnForm::setSignal(QString lv, QString secu){
+void OneConnForm::setSignal(QString lv, QString secu)
+{
     int signal = lv.toInt();
-    if (secu == "--" || secu == ""){
+    if (secu == "--" || secu == "") {
         hasPwd = false;
-    }else{
+    } else {
         hasPwd = true;
     }
 
-    if(signal > 75){
-        if(hasPwd){
+    if (signal > 75) {
+        if (hasPwd) {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-full-pwd.png);}");
-        }else{
+        } else {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-full.png);}");
         }
         signalLv = 1;
     }
-    if(signal > 55 && signal <= 75){
-        if(hasPwd){
+    if (signal > 55 && signal <= 75) {
+        if (hasPwd) {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-high-pwd.png);}");
-        }else{
+        } else {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-high.png);}");
         }
         signalLv = 2;
     }
-    if(signal > 35 && signal <= 55){
-        if(hasPwd){
+    if (signal > 35 && signal <= 55) {
+        if (hasPwd) {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-medium-pwd.png);}");
-        }else{
+        } else {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-medium.png);}");
         }
         signalLv = 3;
     }
-    if(signal > 15 && signal <= 35){
-        if(hasPwd){
+    if (signal > 15 && signal <= 35) {
+        if (hasPwd) {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-low-pwd.png);}");
-        }else{
+        } else {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-low.png);}");
         }
         signalLv = 4;
     }
-    if(signal <= 15){
-        if(hasPwd){
+    if (signal <= 15) {
+        if (hasPwd) {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-none-pwd.png);}");
-        }else{
+        } else {
             ui->lbSignal->setStyleSheet("QLabel{border-radius:0px;background:url(:/res/w/wifi-none.png);}");
         }
         signalLv = 4;
@@ -393,18 +433,25 @@ void OneConnForm::setSignal(QString lv, QString secu){
 void OneConnForm::setWifiInfo(QString str1, QString str2, QString str3)
 {
     if (str1 == "--" || str1 == ""){ str1 = tr("None"); };
-    QString str = "Wi-Fi安全性：" + str1 + "\n信号强度：" + str2 + "%\n物理地址(MAC)：" + str3;
-    ui->lbInfo->setText(str);
+
+    QString strSecurity = QString(tr("WiFi Security："));
+    QString strSignal = QString(tr("Signal："));
+    QString strMAC = QString(tr("MAC："));
+
+    ui->leInfo_1->setText(strSecurity + str1);
+    ui->leInfo_2->setText(strSignal + str2);
+    ui->leInfo_3->setText(strMAC + str3);
 }
 
 void OneConnForm::slotConnWifi()
 {
-//    mw->startLoading();
+    //mw->startLoading();
     this->startWaiting(true);
     emit sigConnWifi(ui->lbName->text());
 }
-void OneConnForm::slotConnWifiPWD(){
-//    mw->startLoading();
+void OneConnForm::slotConnWifiPWD()
+{
+    //mw->startLoading();
     this->startWaiting(true);
     emit sigConnWifiPWD(ui->lbName->text(), ui->lePassword->text());
 }
@@ -427,36 +474,35 @@ void OneConnForm::on_btnDisConn_clicked()
 //点击列表item扩展时会出现该按钮 用于连接网络
 void OneConnForm::on_btnConnSub_clicked()
 {
-    syslog(LOG_DEBUG, "A button named on_btnConnSub about wifi net is clicked.");
-    qDebug()<<"A button named on_btnConnSub about wifi net is clicked.";
-
-    if (ui->lbConned->text() == "--" || ui->lbConned->text() == " "){
-        on_btnConnPWD_clicked();
+    if (mw->is_stop_check_net_state == 1) {
         return;
     }
 
-    mw->is_stop_check_net_state = 1;
-    QThread *t = new QThread();
-    BackThread *bt = new BackThread();
-    bt->moveToThread(t);
-    connect(t, SIGNAL(finished()), t, SLOT(deleteLater()));
-    connect(t, SIGNAL(started()), this, SLOT(slotConnWifi()));
-    connect(this, SIGNAL(sigConnWifi(QString)), bt, SLOT(execConnWifi(QString)));
-    connect(bt, SIGNAL(connDone(int)), mw, SLOT(connWifiDone(int)));
-    connect(bt, SIGNAL(connDone(int)), this, SLOT(slotConnWifiResult(int)));
-    connect(bt, SIGNAL(btFinish()), t, SLOT(quit()));
-    t->start();
+    syslog(LOG_DEBUG, "A button named on_btnConnSub about wifi net is clicked.");
+    qDebug()<<"A button named on_btnConnSub about wifi net is clicked.";
+    toConnectWirelessNetwork();
 }
 
 //无需密码的wifi连接
 void OneConnForm::on_btnConn_clicked()
 {
+    if (mw->is_stop_check_net_state == 1) {
+        return;
+    }
+
     syslog(LOG_DEBUG, "A button named btnConn about wifi net is clicked.");
     qDebug()<<"A button named btnConn about wifi net is clicked.";
+    toConnectWirelessNetwork();
+}
 
-    if (ui->lbConned->text() == "--" || ui->lbConned->text() == " "){
-        on_btnConnPWD_clicked();
-        return;
+void OneConnForm::toConnectWirelessNetwork()
+{
+    if (ui->lbConned->text() == "--" || ui->lbConned->text() == " ") {
+        if (!isWifiConfExist(ui->lbName->text())) {
+            //没有配置文件，使用有密码的wifi连接
+            on_btnConnPWD_clicked();
+            return;
+        }
     }
 
     mw->is_stop_check_net_state = 1;
@@ -500,6 +546,45 @@ void OneConnForm::on_btnHideConn_clicked()
     connHidWifi->show();
 }
 
+bool OneConnForm::isWifiConfExist(QString netName)
+{
+    //dbusWifiMac = ""; //这个函数之前是用来获取已经连接的wifi的MAC地址
+
+    QDBusInterface m_interface("org.freedesktop.NetworkManager",
+                                      "/org/freedesktop/NetworkManager/Settings",
+                                      "org.freedesktop.NetworkManager.Settings",
+                                      QDBusConnection::systemBus() );
+    QDBusReply<QList<QDBusObjectPath>> m_reply = m_interface.call("ListConnections");
+
+    QList<QDBusObjectPath> m_objNets = m_reply.value();
+    foreach (QDBusObjectPath objNet, m_objNets){
+        QDBusInterface m_interface("org.freedesktop.NetworkManager",
+                                  objNet.path(),
+                                  "org.freedesktop.NetworkManager.Settings.Connection",
+                                  QDBusConnection::systemBus());
+        QDBusMessage reply = m_interface.call("GetSettings");
+        const QDBusArgument &dbusArg = reply.arguments().at( 0 ).value<QDBusArgument>();
+        QMap<QString,QMap<QString,QVariant>> map;
+        dbusArg >> map;
+
+        for(QString key : map.keys() ){
+            QMap<QString,QVariant> innerMap = map.value(key);
+            if (key == "connection") {
+                for (QString inner_key : innerMap.keys()) {
+                    if (inner_key == "id"){
+                        if (netName == innerMap.value(inner_key).toString()) {
+                            return true;
+                        }
+                    }
+                }
+            }
+        }
+
+    } // end foreach (QDBusObjectPath objNet, m_objNets)
+
+    return false;
+}
+
 //设置密码隐藏或可见
 void OneConnForm::on_checkBoxPwd_stateChanged(int arg1)
 {
@@ -551,36 +636,39 @@ void OneConnForm::on_btnInfo_clicked()
     QStringList propList = connProp.split("|");
     QString v4method, addr, mask, gateway, dns;
     foreach (QString line, propList) {
-        if(line.startsWith("method:")){
+        if (line.startsWith("method:")) {
             v4method = line.split(":").at(1);
         }
-        if(line.startsWith("addr:")){
+        if (line.startsWith("addr:")) {
             addr = line.split(":").at(1);
         }
-        if(line.startsWith("mask:")){
+        if (line.startsWith("mask:")) {
             mask = line.split(":").at(1);
         }
-        if(line.startsWith("gateway:")){
+        if (line.startsWith("gateway:")) {
             gateway= line.split(":").at(1);
         }
-        if(line.startsWith("dns:")){
+        if (line.startsWith("dns:")) {
             dns = line.split(":").at(1);
         }
     }
-    // qDebug()<<v4method<<addr<<mask<<gateway<<dns;
+    // qDebug()<<"v4method:"<<v4method<<" addr:"<<addr<<" mask:"<<mask<<" gateway:"<<gateway<<" dns:"<<dns;
 
     cf->setProp(ui->lbName->text(), v4method, addr, mask, gateway, dns, this->isActive);
 
-    //cf->move(primaryGeometry.width() / 2 - cf->width() / 2, primaryGeometry.height() / 2 - cf->height() / 2);
+    cf->move(primaryGeometry.width() / 2 - cf->width() / 2, primaryGeometry.height() / 2 - cf->height() / 2);
     cf->show();
     cf->raise();
+
+    bt->deleteLater();
 }
 
 // Wifi连接结果，0成功 1失败 2没有配置文件
-void OneConnForm::slotConnWifiResult(int connFlag){
+void OneConnForm::slotConnWifiResult(int connFlag)
+{
     qDebug()<<"Function slotConnWifiResult receives a number: "<<connFlag;
 
-    if(connFlag == 2){
+    if (connFlag == 2) {
         mw->currSelNetName = "";
         emit selectedOneWifiForm(ui->lbName->text(), H_WIFI_ITEM_SMALL_EXTEND);
 
@@ -588,12 +676,13 @@ void OneConnForm::slotConnWifiResult(int connFlag){
         ui->wbg->hide();
         ui->wbg_2->show();
         ui->wbg_3->hide();
-        ui->lbInfo->hide();
+        ui->leInfo_1->hide();
+        ui->leInfo_2->hide();
+        ui->leInfo_3->hide();
         ui->btnHideConn->hide();
         ui->btnDisConn->hide();
         ui->btnConn->hide();
         ui->btnConnSub->hide();
-        ui->lbInfo->hide();
         ui->line->move(X_LINE_SMALL_EXTEND, Y_LINE_SMALL_EXTEND);
 
         ui->lePassword->show();
@@ -601,57 +690,73 @@ void OneConnForm::slotConnWifiResult(int connFlag){
         ui->btnConnPWD->show();
 
         this->isSelected = true;
+        mw->is_stop_check_net_state = 0;
     }
 
-    if(connFlag == 1){
+    if (connFlag == 1) {
         // 使用配置文件连接失败，需要删除该配置文件
         QString txt(tr("Conn Wifi Failed"));//"连接 Wifi 失败"
         syslog(LOG_DEBUG, "Try to connect wifi named %s, but failed, will delete it's configuration file", ui->lbName->text().toUtf8().data());
 
-        //m_notify->execNotifySend(txt);
         KylinDBus kylindbus;
         kylindbus.showDesktopNotify(txt);
         //QString cmd = "export LANG='en_US.UTF-8';export LANGUAGE='en_US';nmcli connection delete '" + ui->lbName->text() + "';notify-send '" + txt + "...' -t 3800";
-        //int status = system(cmd.toUtf8().data());
-        //if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection delete' in function 'slotConnWifiResult' failed");}
+        QString cmd = "export LANG='en_US.UTF-8';export LANGUAGE='en_US';nmcli connection delete '" + ui->lbName->text() + "'";
+        int status = system(cmd.toUtf8().data());
+        if (status != 0) {
+            syslog(LOG_ERR, "execute 'nmcli connection delete' in function 'slotConnWifiResult' failed");
+        }
+
+        mw->is_stop_check_net_state = 0;
     }
 
     // 设置全局变量，当前连接Wifi的信号强度
     currentActWifiSignalLv = signalLv;
 
     this->stopWaiting();
-//    if (connFlag != 0){
-//        mw->stopLoading();
-//    }
+    //if (connFlag != 0){
+    //    mw->stopLoading();
+    //}
 }
 
-void OneConnForm::waitAnimStep(){
+void OneConnForm::waitAnimStep()
+{
     QString qpmQss = "QLabel{background-image:url(':/res/s/conning-a/";
     qpmQss.append(QString::number(this->waitPage));
     qpmQss.append(".png');}");
     ui->lbWaitingIcon->setStyleSheet(qpmQss);
 
     this->waitPage --;
-
-    if(this->waitPage < 1){
-        this->waitPage = TOTAL_PAGE;
+    if (this->waitPage < 1) {
+        this->waitPage = TOTAL_PAGE; //循环播放8张图片
     }
+
     this->countCurrentTime += FRAME_SPEED;
-    if (this->countCurrentTime >= LIMIT_TIME){
-        this->stopWaiting();
+    if (this->countCurrentTime >= LIMIT_TIME) {
+        QString cmd = "kill -9 $(pidof nmcli)"; //杀掉当前正在进行的有关nmcli命令的进程
+        int status = system(cmd.toUtf8().data());
+        if (status != 0) {
+            qDebug()<<"execute 'kill -9 $(pidof nmcli)' in function 'waitAnimStep' failed";
+            syslog(LOG_ERR, "execute 'kill -9 $(pidof nmcli)' in function 'waitAnimStep' failed");
+        }
+
+        this->stopWaiting(); //动画超出时间限制，强制停止动画
+
+        mw->is_stop_check_net_state = 0;
     }
 }
 
-void OneConnForm::startWaiting(bool isConn){
+void OneConnForm::startWaiting(bool isConn)
+{
     this->isWaiting = true;
-    if (isConn){
+    if (isConn) {
         ui->lbWaiting->setStyleSheet("QLabel{border:0px;border-radius:4px;background-color:rgba(61,107,229,1);}");
-    }else{
+    } else {
         ui->btnDisConn->hide();
         ui->lbWaiting->setStyleSheet("QLabel{border:0px;border-radius:4px;background-color:rgba(255,255,255,0.12);}");
     }
     this->countCurrentTime = 0;
-    this->waitPage = TOTAL_PAGE;
+    this->waitPage = TOTAL_PAGE; //总共有8张图片
     this->waitTimer->start(FRAME_SPEED);
     ui->lbWaiting->show();
     ui->lbWaitingIcon->show();
@@ -659,7 +764,8 @@ void OneConnForm::startWaiting(bool isConn){
     mw->setTrayLoading(true);
 }
 
-void OneConnForm::stopWaiting(){
+void OneConnForm::stopWaiting()
+{
     this->isWaiting = false;
     this->waitTimer->stop();
     ui->lbWaiting->hide();
