@@ -12,85 +12,99 @@
     <name>ConfForm</name>
     <message>
         <location filename="../src/confform.cpp" line="39"/>
-        <location filename="../src/confform.cpp" line="288"/>
         <source>edit network</source>
         <translation>编辑网络设置</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="52"/>
-        <source>Network name: </source>
+        <location filename="../src/confform.cpp" line="106"/>
+        <source>LAN name: </source>
         <translation type="unfinished">网络名称：</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="53"/>
+        <location filename="../src/confform.cpp" line="107"/>
         <source>Method: </source>
         <translation>编辑IP设置: </translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="54"/>
+        <location filename="../src/confform.cpp" line="108"/>
         <source>Address: </source>
         <translation>IP地址: </translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="55"/>
+        <location filename="../src/confform.cpp" line="109"/>
         <source>Netmask: </source>
         <translation>子网掩码: </translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="56"/>
+        <location filename="../src/confform.cpp" line="110"/>
         <source>Gateway: </source>
         <translation>默认网关: </translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="57"/>
+        <location filename="../src/confform.cpp" line="111"/>
         <source>DNS 1: </source>
         <translation>首选DNS: </translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="58"/>
+        <location filename="../src/confform.cpp" line="112"/>
         <source>DNS 2: </source>
         <translation>备选DNS: </translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="60"/>
+        <location filename="../src/confform.cpp" line="114"/>
         <source>Edit Conn</source>
         <translation>网络设置</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="61"/>
+        <location filename="../src/confform.cpp" line="115"/>
         <source>Auto(DHCP)</source>
         <translation>自动(DHCP)</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="62"/>
+        <location filename="../src/confform.cpp" line="116"/>
         <source>Manual</source>
         <translation>手动</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="72"/>
+        <location filename="../src/confform.cpp" line="126"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="73"/>
+        <location filename="../src/confform.cpp" line="127"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="74"/>
+        <location filename="../src/confform.cpp" line="128"/>
         <source>Ok</source>
         <translation type="unfinished">确定</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="216"/>
+        <location filename="../src/confform.cpp" line="220"/>
+        <source>Can not create new wired network for without wired card</source>
+        <translation type="unfinished">缺少有线网卡 无法新建网络</translation>
+    </message>
+    <message>
+        <location filename="../src/confform.cpp" line="236"/>
         <source>New network already created</source>
         <translation type="unfinished">已创建新的有线网络</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="254"/>
+        <location filename="../src/confform.cpp" line="276"/>
         <source>New network settings already finished</source>
         <translation type="unfinished">新的网络配置已经完成</translation>
     </message>
+    <message>
+        <location filename="../src/confform.cpp" line="309"/>
+        <source>Edit Network</source>
+        <translation type="unfinished">编辑网络设置</translation>
+    </message>
+    <message>
+        <location filename="../src/confform.cpp" line="344"/>
+        <source>Add Wired Network</source>
+        <translation type="unfinished">新建有线网络</translation>
+    </message>
     <message>
         <source>create wired network successfully</source>
         <translation type="obsolete">已创建新的有线网络</translation>
@@ -100,60 +114,55 @@
         <translation type="obsolete">新的设置已经生效</translation>
     </message>
     <message>
-        <location filename="../src/confform.cpp" line="270"/>
+        <location filename="../src/confform.cpp" line="285"/>
         <source>New settings already effective</source>
         <translation>新的设置已经生效</translation>
     </message>
-    <message>
-        <location filename="../src/confform.cpp" line="323"/>
-        <source>add wired network</source>
-        <translation type="unfinished">新建有线网络</translation>
-    </message>
 </context>
 <context>
     <name>DlgConnHidWifi</name>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="69"/>
-        <source>Add hidden Wi-Fi</source>
-        <translation>加入隐藏Wi-Fi</translation>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="77"/>
+        <source>Add Hidden Wi-Fi</source>
+        <translation type="unfinished">加入隐藏Wi-Fi</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="70"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="78"/>
         <source>Connection</source>
         <translation>连接设置:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="71"/>
-        <source>Network name</source>
-        <translation>网络名称:</translation>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="79"/>
+        <source>Wi-Fi name</source>
+        <translation type="unfinished">网络名称:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="72"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="80"/>
         <source>Wi-Fi security</source>
         <translation>Wi-Fi 安全性:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="73"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="81"/>
         <source>Cancel</source>
         <translation type="unfinished">取消</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="74"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="82"/>
         <source>Connect</source>
         <translation type="unfinished">连接</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="76"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="84"/>
         <source>C_reate…</source>
         <translation type="unfinished">新建...</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="95"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="105"/>
         <source>None</source>
         <translation>无</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="96"/>
+        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="106"/>
         <source>WPA &amp; WPA2 Personal</source>
         <translation>WPA 及 WPA2 个人</translation>
     </message>
@@ -1129,52 +1138,52 @@
         <translation>连接到隐藏 Wi-Fi 网络</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="74"/>
-        <source>Add hidden Wi-Fi</source>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="82"/>
+        <source>Add Hidden Wi-Fi</source>
         <translation type="unfinished">加入隐藏Wi-Fi</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="75"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="83"/>
         <source>Connection</source>
         <translation type="unfinished">连接设置:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="76"/>
-        <source>Network name</source>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="84"/>
+        <source>Wi-Fi name</source>
         <translation type="unfinished">网络名称:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="77"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="85"/>
         <source>Wi-Fi security</source>
         <translation type="unfinished">Wi-Fi 安全性:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="78"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="86"/>
         <source>Password</source>
         <translation type="unfinished">密码:</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="79"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="87"/>
         <source>Cancel</source>
         <translation type="unfinished">取消</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="80"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="88"/>
         <source>Connect</source>
         <translation type="unfinished">连接</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="82"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="90"/>
         <source>C_reate…</source>
         <translation type="unfinished">新建...</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="101"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="113"/>
         <source>None</source>
         <translation type="unfinished">无</translation>
     </message>
     <message>
-        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="102"/>
+        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="114"/>
         <source>WPA &amp; WPA2 Personal</source>
         <translation type="unfinished">WPA 及 WPA2 个人</translation>
     </message>
@@ -1246,16 +1255,15 @@
 <context>
     <name>KylinDBus</name>
     <message>
-        <location filename="../src/kylin-dbus-interface.cpp" line="490"/>
         <source>kylin network applet desktop message</source>
-        <translation type="unfinished">麒麟网络工具信息提示</translation>
+        <translation type="obsolete">麒麟网络工具信息提示</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="../src/mainwindow.ui" line="14"/>
-        <location filename="../src/mainwindow.cpp" line="576"/>
+        <location filename="../src/mainwindow.cpp" line="532"/>
         <source>kylin-nm</source>
         <translation>网络工具</translation>
     </message>
@@ -1264,14 +1272,14 @@
         <translation type="vanished">网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="385"/>
-        <location filename="../src/mainwindow.cpp" line="599"/>
+        <location filename="../src/mainwindow.cpp" line="377"/>
+        <location filename="../src/mainwindow.cpp" line="537"/>
         <source>Advanced</source>
-        <translation>网络配置</translation>
+        <translation>设置网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="344"/>
-        <location filename="../src/mainwindow.cpp" line="1234"/>
+        <location filename="../src/mainwindow.cpp" line="340"/>
+        <location filename="../src/mainwindow.cpp" line="1180"/>
         <source>Ethernet</source>
         <translation>有线网络</translation>
     </message>
@@ -1280,8 +1288,8 @@
         <translation type="vanished">加入网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="350"/>
-        <location filename="../src/mainwindow.cpp" line="1330"/>
+        <location filename="../src/mainwindow.cpp" line="346"/>
+        <location filename="../src/mainwindow.cpp" line="1239"/>
         <source>Wifi</source>
         <translation>无线网络</translation>
     </message>
@@ -1294,97 +1302,100 @@
         <translation type="vanished">已关闭</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="365"/>
+        <location filename="../src/mainwindow.cpp" line="357"/>
         <source>HotSpot</source>
         <translation>个人热点</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="367"/>
         <source>FlyMode</source>
         <translation>飞行模式</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="598"/>
+        <location filename="../src/mainwindow.cpp" line="536"/>
         <source>Show MainWindow</source>
         <translation>显示网络连接界面</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1297"/>
-        <location filename="../src/mainwindow.cpp" line="1354"/>
-        <location filename="../src/mainwindow.cpp" line="1425"/>
-        <location filename="../src/mainwindow.cpp" line="1557"/>
-        <location filename="../src/mainwindow.cpp" line="2213"/>
-        <location filename="../src/mainwindow.cpp" line="2297"/>
+        <location filename="../src/mainwindow.cpp" line="1143"/>
+        <source>No wireless card detected</source>
+        <translation type="unfinished">未检测到无线网卡</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1279"/>
+        <location filename="../src/mainwindow.cpp" line="1356"/>
+        <location filename="../src/mainwindow.cpp" line="1504"/>
+        <location filename="../src/mainwindow.cpp" line="2200"/>
+        <location filename="../src/mainwindow.cpp" line="2289"/>
         <source>Not connected</source>
         <translation>当前未连接任何网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1299"/>
-        <location filename="../src/mainwindow.cpp" line="1357"/>
-        <location filename="../src/mainwindow.cpp" line="1427"/>
-        <location filename="../src/mainwindow.cpp" line="1480"/>
-        <location filename="../src/mainwindow.cpp" line="1481"/>
-        <location filename="../src/mainwindow.cpp" line="1560"/>
-        <location filename="../src/mainwindow.cpp" line="1631"/>
-        <location filename="../src/mainwindow.cpp" line="1765"/>
-        <location filename="../src/mainwindow.cpp" line="2215"/>
-        <location filename="../src/mainwindow.cpp" line="2299"/>
+        <location filename="../src/mainwindow.cpp" line="1282"/>
+        <location filename="../src/mainwindow.cpp" line="1358"/>
+        <location filename="../src/mainwindow.cpp" line="1424"/>
+        <location filename="../src/mainwindow.cpp" line="1425"/>
+        <location filename="../src/mainwindow.cpp" line="1507"/>
+        <location filename="../src/mainwindow.cpp" line="1586"/>
+        <location filename="../src/mainwindow.cpp" line="1738"/>
+        <location filename="../src/mainwindow.cpp" line="2202"/>
+        <location filename="../src/mainwindow.cpp" line="2291"/>
         <source>Disconnected</source>
         <translation>未连接</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1503"/>
+        <location filename="../src/mainwindow.cpp" line="1449"/>
         <source>No Other Wired Network Scheme</source>
         <translation type="unfinished">列表中无其他有线网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1653"/>
+        <location filename="../src/mainwindow.cpp" line="1608"/>
         <source>No Other Wireless Network Scheme</source>
         <translation type="unfinished">未检测到其他无线网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="2125"/>
+        <location filename="../src/mainwindow.cpp" line="2111"/>
         <source>Wired net is disconnected</source>
         <translation type="unfinished">断开有线网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="2153"/>
+        <location filename="../src/mainwindow.cpp" line="2139"/>
         <source>Wi-Fi is disconnected</source>
         <translation type="unfinished">断开无线网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="2583"/>
+        <location filename="../src/mainwindow.cpp" line="2518"/>
         <source>Confirm your Wi-Fi password or usable of wireless card</source>
         <translation type="unfinished">请确认Wi-Fi密码或无线设备</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="231"/>
+        <location filename="../src/mainwindow.cpp" line="225"/>
         <source>Ethernet Networks</source>
         <translation>可用有线网络列表</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="240"/>
-        <source>Create Lan Net</source>
+        <location filename="../src/mainwindow.cpp" line="234"/>
+        <source>New LAN</source>
         <translation type="unfinished">新建网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="263"/>
-        <source>Add Hide Network</source>
+        <location filename="../src/mainwindow.cpp" line="257"/>
+        <source>Hide WiFi</source>
         <translation>加入网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="293"/>
+        <location filename="../src/mainwindow.cpp" line="287"/>
         <source>No usable network in the list</source>
         <translation type="unfinished">列表暂无可连接网络</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1462"/>
-        <location filename="../src/mainwindow.cpp" line="1608"/>
-        <source>Connected</source>
+        <location filename="../src/mainwindow.cpp" line="1403"/>
+        <location filename="../src/mainwindow.cpp" line="1564"/>
+        <source>NetOn,</source>
         <translation>已连接，</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="254"/>
+        <location filename="../src/mainwindow.cpp" line="248"/>
         <source>Wifi Networks</source>
         <translation>可用无线网络列表</translation>
     </message>
@@ -1397,14 +1408,12 @@
         <translation type="vanished">打开无线网开关前保持有线网开关打开</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1208"/>
         <source>please insert the wireless network adapter</source>
-        <translation>请先插入无线网卡</translation>
+        <translation type="vanished">请先插入无线网卡</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1269"/>
         <source>Abnormal connection exist, program will delete it</source>
-        <translation>正在断开异常连接的网络</translation>
+        <translation type="vanished">正在断开异常连接的网络</translation>
     </message>
     <message>
         <source>update Wi-Fi list now, click again</source>
@@ -1415,17 +1424,17 @@
         <translation type="vanished">正在更新 Wi-Fi列表</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="2436"/>
+        <location filename="../src/mainwindow.cpp" line="2474"/>
         <source>Conn Ethernet Success</source>
         <translation>连接有线网络成功</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="2450"/>
+        <location filename="../src/mainwindow.cpp" line="2486"/>
         <source>Conn Ethernet Fail</source>
         <translation>连接有线网络失败</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="2572"/>
+        <location filename="../src/mainwindow.cpp" line="2509"/>
         <source>Conn Wifi Success</source>
         <translation>连接无线网络成功</translation>
     </message>
@@ -1433,9 +1442,8 @@
 <context>
     <name>NotifySend</name>
     <message>
-        <location filename="../src/notifysend.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished">--</translation>
+        <translation type="obsolete">--</translation>
     </message>
 </context>
 <context>
@@ -1454,29 +1462,34 @@
         <translation type="vanished">设置</translation>
     </message>
     <message>
-        <location filename="../src/oneconnform.cpp" line="33"/>
-        <location filename="../src/oneconnform.cpp" line="34"/>
-        <location filename="../src/oneconnform.cpp" line="35"/>
-        <location filename="../src/oneconnform.cpp" line="37"/>
+        <location filename="../src/oneconnform.cpp" line="42"/>
+        <location filename="../src/oneconnform.cpp" line="43"/>
+        <location filename="../src/oneconnform.cpp" line="44"/>
+        <location filename="../src/oneconnform.cpp" line="46"/>
         <source>Connect</source>
         <translation>连接</translation>
     </message>
     <message>
-        <location filename="../src/oneconnform.cpp" line="36"/>
+        <location filename="../src/oneconnform.cpp" line="45"/>
         <source>Disconnect</source>
         <translation>断开</translation>
     </message>
     <message>
-        <location filename="../src/oneconnform.cpp" line="38"/>
-        <location filename="../src/oneconnform.cpp" line="252"/>
+        <location filename="../src/oneconnform.cpp" line="47"/>
+        <location filename="../src/oneconnform.cpp" line="285"/>
         <source>Input Password...</source>
         <translation type="unfinished">输入密码...</translation>
     </message>
     <message>
-        <location filename="../src/oneconnform.cpp" line="318"/>
+        <location filename="../src/oneconnform.cpp" line="357"/>
         <source>Connect to Hidden Wi-Fi Network</source>
         <translation>连接到隐藏 Wi-Fi 网络</translation>
     </message>
+    <message>
+        <location filename="../src/oneconnform.cpp" line="438"/>
+        <source>Signal：</source>
+        <translation type="unfinished">信号强度：</translation>
+    </message>
     <message>
         <source>Public</source>
         <translation type="vanished">开放</translation>
@@ -1486,16 +1499,27 @@
         <translation type="vanished">安全</translation>
     </message>
     <message>
+        <location filename="../src/oneconnform.cpp" line="368"/>
         <source>Rate</source>
-        <translation type="vanished">速率</translation>
+        <translation>速率</translation>
     </message>
     <message>
-        <location filename="../src/oneconnform.cpp" line="394"/>
+        <location filename="../src/oneconnform.cpp" line="435"/>
         <source>None</source>
         <translation type="unfinished">无</translation>
     </message>
     <message>
-        <location filename="../src/oneconnform.cpp" line="607"/>
+        <location filename="../src/oneconnform.cpp" line="437"/>
+        <source>WiFi Security：</source>
+        <translation type="unfinished">WiFi安全性：</translation>
+    </message>
+    <message>
+        <location filename="../src/oneconnform.cpp" line="439"/>
+        <source>MAC：</source>
+        <translation type="unfinished">物理地址：</translation>
+    </message>
+    <message>
+        <location filename="../src/oneconnform.cpp" line="689"/>
         <source>Conn Wifi Failed</source>
         <translation>连接无线网络失败</translation>
     </message>
@@ -1523,14 +1547,42 @@
         <translation>断开</translation>
     </message>
     <message>
-        <location filename="../src/onelancform.cpp" line="221"/>
-        <location filename="../src/onelancform.cpp" line="225"/>
-        <source>no configuration</source>
+        <location filename="../src/onelancform.cpp" line="243"/>
+        <location filename="../src/onelancform.cpp" line="247"/>
+        <source>No Configuration</source>
         <translation type="unfinished">未配置</translation>
     </message>
+    <message>
+        <location filename="../src/onelancform.cpp" line="250"/>
+        <source>IPv4：</source>
+        <translation type="unfinished">IPv4地址：</translation>
+    </message>
+    <message>
+        <location filename="../src/onelancform.cpp" line="251"/>
+        <source>IPv6：</source>
+        <translation type="unfinished">IPv6地址：</translation>
+    </message>
+    <message>
+        <location filename="../src/onelancform.cpp" line="252"/>
+        <source>BandWidth：</source>
+        <translation type="unfinished">带宽：</translation>
+    </message>
+    <message>
+        <location filename="../src/onelancform.cpp" line="253"/>
+        <source>MAC：</source>
+        <translation type="unfinished">物理地址：</translation>
+    </message>
     <message>
         <source>Auto</source>
         <translation type="obsolete">自动</translation>
     </message>
 </context>
+<context>
+    <name>Utils</name>
+    <message>
+        <location filename="../src/utils.cpp" line="87"/>
+        <source>kylin network applet desktop message</source>
+        <translation type="unfinished">麒麟网络工具信息提示</translation>
+    </message>
+</context>
 </TS>
